@@ -33,3 +33,17 @@ def test_ibmq_runner_can_run_batches_larger_then_natively_supported_by_backend(
 
     result = ibmq_runner.run_batch_and_measure(circuits, 1000)
     assert len(result) == len(circuits)
+
+
+def test_ibmq_runner_discards_extra_measurements_if_exact_num_measurements_is_true():
+    ibmq_runner = create_ibmq_runner(
+        api_token=os.getenv("ZAPATA_IBMQ_API_TOKEN"),
+        backend_name="ibmq_qasm_simulator",
+        retry_delay_seconds=1,
+        discard_extra_measurements=True,
+    )
+    circuits = [Circuit([H(0), CNOT(0, 1)])] * 3
+    n_samples = [5, 10, 15]
+    result = ibmq_runner.run_batch_and_measure(circuits, n_samples=n_samples)
+
+    assert [len(r.bitstrings) for r in result] == n_samples
